@@ -45,7 +45,7 @@ func (d Domain) GetFullDomain() string {
 }
 
 // GetSubDomain 获得子域名，为空返回@
-// 阿里云/dnspod/namecheap 需要
+// 阿里云/腾讯云/dnspod/namecheap 需要
 func (d Domain) GetSubDomain() string {
 	if d.SubDomain != "" {
 		return d.SubDomain
@@ -123,7 +123,12 @@ func checkParseDomains(domainArr []string) (domains []*Domain) {
 				domain.DomainName = sp[length-2] + "." + sp[length-1]
 				// 如包含在org.cn等顶级域名下，后三个才为用户主域名
 				for _, staticMainDomain := range staticMainDomains {
-					if staticMainDomain == domain.DomainName {
+					// 移除 domain.DomainName 的查询字符串以便与 staticMainDomain 进行比较。
+					// 查询字符串是 URL ? 后面的部分。
+					// 查询字符串的存在会导致顶级域名无法与 staticMainDomain 精确匹配，从而被误认为二级域名。
+					// 示例："com.cn?param=value" 将被替换为 "com.cn"。
+					// https://github.com/jeessy2/ddns-go/issues/714
+					if staticMainDomain == strings.Split(domain.DomainName, "?")[0] {
 						domain.DomainName = sp[length-3] + "." + domain.DomainName
 						break
 					}
